from demands import JSONServiceClient


class ControlInterfaceApiClient(object):
    """
    Client for Control Interface Service.

    :param str auth_token:

        An access token.

    :param str api_url:
        The full URL of the API.

    """

    def __init__(self, auth_token, api_url, session=None):
        headers = {'Authorization': 'Token ' + auth_token}
        if session is None:
            session = JSONServiceClient(url=api_url,
                                        headers=headers)
        self.session = session

    def get_user_service_tokens(self, params=None):
        return self.session.get('/userservicetoken/', params=params)

    def generate_user_service_tokens(self, user):
        return self.session.post('/userservicetoken/generate/', data=user)

    def get_service(self, service):
        # return None on 404 becuase that means a service not found
        self.session.is_acceptable = \
            lambda response, request_params: response.status_code in [404, 200]
        result = self.session.get('/service/%s/' % service)
        if "detail" in result and result["detail"] == "Not found.":
            return None
        return result

    def get_services(self, params=None):
        return self.session.get('/service/', params=params)

    def get_service_status(self, service):
        params = {"service": service, "ordering": "-created_at"}
        return self.session.get('/status/', params=params)

    def get_user_dashboards(self, user_id):
        params = {
            "user_id": user_id
        }
        return self.session.get('/userdashboard/', params=params)

    def get_dashboard(self, dashboard):
        return self.session.get('/dashboard/%s/' % dashboard)



from demands import JSONServiceClient, HTTPServiceClient


class MessageSenderApiClient(object):
    """
    Client for Message Sender Service.

    :param str auth_token:

        An access token.

    :param str api_url:
        The full URL of the API.

    """

    def __init__(self, auth_token, api_url, session=None, session_http=None):
        if session is None:
            session = JSONServiceClient(
                url=api_url, headers={'Authorization': 'Token ' + auth_token})

        if session_http is None:
            session_http = HTTPServiceClient(
                url=api_url, headers={'Authorization': 'Token ' + auth_token})
        self.session = session
        self.session_http = session_http

    def create_outbound(self, payload):
        return self.session.post('/outbound/', data=payload)



from demands import JSONServiceClient


class IdentityStoreApiClient(object):
    """
    Client for Identity Store Service.

    :param str auth_token:

        An access token.

    :param str api_url:
        The full URL of the API.

    """

    def __init__(self, auth_token, api_url, session=None):
        headers = {'Authorization': 'Token ' + auth_token}
        if session is None:
            session = JSONServiceClient(url=api_url,
                                        headers=headers)
        self.session = session

    def get_identities(self, params=None):
        return self.session.get('/identities/', params=params)

    def get_identity(self, identity):
        # return None on 404 becuase that means an identity not found
        self.session.is_acceptable = \
            lambda response, request_params: response.status_code in [404, 200]
        result = self.session.get('/identities/%s/' % identity)
        if "detail" in result and result["detail"] == "Not found.":
            return None
        return result

    def get_identity_by_address(self, address_type, address_value):
        params = {"details__addresses__%s" % address_type: address_value}
        return self.session.get('/identities/search/', params=params)

    def update_identity(self, identity, data=None):
        return self.session.patch('/identities/%s/' % identity, data=data)



from demands import JSONServiceClient


class HubApiClient(object):
    """
    Client for Hub Service (registration and changes).

    :param str auth_token:

        An access token.

    :param str api_url:
        The full URL of the API.

    """

    def __init__(self, auth_token, api_url, session=None):
        headers = {'Authorization': 'Token ' + auth_token}
        if session is None:
            session = JSONServiceClient(url=api_url,
                                        headers=headers)
        self.session = session

    def get_registrations(self, params=None):
        """
        Filter params can include
        'stage', 'mother_id', 'validated', 'source', 'created_before'
        'created_after' """
        return self.session.get('/registrations/', params=params)

    def get_registration(self, registration):
        return self.session.get('/registrations/%s/' % registration)

    def create_registration(self, registration):
        return self.session.post('/registration/', data=registration)

    def get_changes(self, params=None):
        """
        Filter params can include
        'action', 'mother_id', 'validated', 'source', 'created_before'
        'created_after' """
        return self.session.get('/changes/', params=params)

    def get_change(self, change):
        return self.session.get('/changes/%s/' % change)

    def create_change(self, change):
        return self.session.post('/change/', data=change)



#!/usr/bin/env python
# -*- coding: utf-8 -*-


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('requirements.txt') as req_file:
    requirements = req_file.read().split('\n')

with open('requirements-dev.txt') as req_file:
    requirements_dev = req_file.read().split('\n')

with open('VERSION') as fp:
    version = fp.read().strip()

setup(
    name='seed-services-client',
    version=version,
    description="Python client for Seed Service REST APIs",
    long_description=readme,
    author="Praekelt Foundation and Individual Contributors",
    author_email='dev@praekeltfoundation.org',
    url='https://github.com/praekeltfoundation/seed-services-client',
    packages=[
        'seed_services_client',
    ],
    package_dir={'seed_services_client':
                 'seed_services_client'},
    include_package_data=True,
    install_requires=requirements,
    license="BSD",
    zip_safe=False,
    keywords='seed-services-client',
    classifiers=[
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python :: 2.7',
    ]
)



"""Seed Services client library."""

from .identity_store import IdentityStoreApiClient
from .stage_based_messaging import StageBasedMessagingApiClient
from .auth import AuthApiClient
from .control_interface import ControlInterfaceApiClient
from .hub import HubApiClient
from .message_sender import MessageSenderApiClient

__version__ = "0.7.0"

__all__ = [
    'IdentityStoreApiClient', 'StageBasedMessagingApiClient', 'AuthApiClient',
    'ControlInterfaceApiClient', 'HubApiClient', 'MessageSenderApiClient'
]
